[Desktop Entry]
DefaultProfile=Snorriheim.profile

[Favorite Profiles]
Favorites=

[MainWindow]
Height 1050=602
Height 1080=446
State=AAAA/wAAAAD9AAAAAAAABI8AAAGlAAAABAAAAAQAAAAIAAAACPwAAAAA
ToolBarsMovable=Disabled
Width 1680=1239
Width 2560=1167
