[Background]
Color=0,0,0

[BackgroundIntense]
Color=104,104,104

[Color0]
Color=0,0,0

[Color0Intense]
Color=104,104,104

[Color1]
Color=178,24,24

[Color1Intense]
Color=255,84,84

[Color2]
Color=24,178,24

[Color2Intense]
Color=84,255,84

[Color3]
Color=178,104,24

[Color3Intense]
Color=255,255,84

[Color4]
Color=24,24,178

[Color4Intense]
Color=84,84,255

[Color5]
Color=178,24,178

[Color5Intense]
Color=255,84,255

[Color6]
Color=24,178,178

[Color6Intense]
Color=84,255,255

[Color7]
Color=178,178,178

[Color7Intense]
Color=255,255,255

[Foreground]
Color=178,178,178

[ForegroundIntense]
Color=255,255,255

[General]
Description=Linux Colours
Opacity=0.81999999999999995
Wallpaper=
