[user]
        email = d.stonier@gmail.com
        name = Daniel Stonier
[push]
        default = simple
[core]
        editor = vim
[http]
        postBuffer = 524288000
[credential]
	helper = cache --timeout=360000

