{
	"common": {
		"term_truecolor": false
	},
	"ext": {
		"ipython": {
			"colorscheme": "default",
			"theme": "in",
			"local_themes": {
				"rewrite": "rewrite",
				"out": "out",
				"in2": "in2"
			}
		},
		"pdb": {
			"colorscheme": "default",
			"theme": "default"
		},
		"shell": {
			"colorscheme": "default",
			"theme": "mine",
			"local_themes": {
				"continuation": "continuation",
				"select": "select"
			}
		},
		"tmux": {
			"colorscheme": "default",
			"theme": "default"
		},
		"vim": {
			"colorscheme": "default",
			"theme": "default",
			"local_themes": {
				"__tabline__": "tabline",

				"cmdwin": "cmdwin",
				"help": "help",
				"quickfix": "quickfix",

				"powerline.matchers.vim.plugin.nerdtree.nerdtree": "plugin_nerdtree",
				"powerline.matchers.vim.plugin.commandt.commandt": "plugin_commandt",
				"powerline.matchers.vim.plugin.gundo.gundo": "plugin_gundo",
				"powerline.matchers.vim.plugin.gundo.gundo_preview": "plugin_gundo-preview"
			}
		},
		"wm": {
			"colorscheme": "default",
			"theme": "default"
		}
	}
}
