[Hotkey]
# Trigger Input Method
TriggerKey=ALT_RALT
# Use extra trigger key only after using it to inactivate
# Available Value:
# True False
#UseExtraTriggerKeyOnlyWhenUseItToInactivate=True
# Extra key for trigger input method
# Available Value:
# R_CTRL
# R_SHIFT
# L_SHIFT
# L_CTRL
# ALT_L_SHIFT
# ALT_R_SHIFT
# CTRL Both
# SHIFT Both
# L_ALT
# R_ALT
# ALT Both
# Left Super
# Right Super
# Super Both
# Ctrl+Left Super
# Ctrl+Right Super
# Super+Left Ctrl
# Super+Right Ctrl
# Disabled
# Custom
#SwitchKey=L_SHIFT
# Custom switch key
#CustomSwitchKey=
# Activate input method
#ActivateKey=
# Inactivate Input Method
#InactivateKey=
# Enable Hotkey to scroll Between Input Method
# Available Value:
# True False
#IMSwitchKey=True
# Include Inactivate when scrolling between Input Method
# Available Value:
# True False
#IMSwitchIncludeInactive=False
# Scroll between Input Method
# Available Value:
# CTRL_SHIFT
# ALT_SHIFT
# CTRL_SUPER
# ALT_SUPER
#IMSwitchHotkey=CTRL_SHIFT
# Reload configuration
#ReloadConfig=CTRL_5
# Interval of Two Key Input
#TimeInterval=250
# Switching Virtual Keyboard
#VKSwitchKey=CTRL_ALT_B
# Switching Remind Mode
#RemindSwitchKey=
# Switching Full Width Character Mode
#FullWidthSwitchKey=
# Switch Full Width Punc Mode
#PuncSwitchKey=CTRL_.
# Prev Page
#PrevPageKey=- UP
# Next Page
#NextPageKey== DOWN
# Choose Second and Third Candidate Word
#SecondThirdCandWordKey=
# Saving All Config and Input History
#SaveAllKey=CTRL_ALT_S
# Switch Embedded Preedit
#SwitchPreedit=CTRL_ALT_P
# Previous Candidate Word
#PrevWord=SHIFT_TAB
# Next Candidate Word
#NextWord=TAB

[Program]
# Seconds sleep before fcitx really start
#DelayStart=0
# Share State Among Window
# Available Value:
# No
# All
# PerProgram
#ShareStateAmongWindow=No
# Default Input Method State
# Available Value:
# Inactive
# Active
#DefaultInputMethodState=Inactive

[Output]
# Type half width Punc After a Number
# Available Value:
# True False
#HalfPuncAfterNumber=True
# Disable Paging in Remind Mode
# Available Value:
# True False
#RemindModeDisablePaging=True
# Commit when toggle state
# Available Value:
# True False
#SendTextWhenSwitchEng=True
# Candidate Word Number
#CandidateWordNumber=5
# Give the tips of Phrase
# Available Value:
# True False
#PhraseTips=True
# Do not commit preedit text when unfocus a window
# Available Value:
# True False
#DontCommitPreeditWhenUnfocus=False

[Appearance]
# Show Input Method Hint After Input method changed
# Available Value:
# True False
#ShowInputWindowAfterTriggering=True
# Show Input Method Hint After Input method changed and Focus in
# Available Value:
# True False
#ShowInputWindowWhenFocusIn=False
# Input Method Hint will be only shown when state is active
# Available Value:
# True False
#ShowInputWindowOnlyWhenActive=True
# Show Input Speed
# Available Value:
# True False
#ShowInputSpeed=False
# Show Version
# Available Value:
# True False
#ShowVersion=False
# Do not show input window if there is only preedit string
# Available Value:
# True False
#HideInputWindowWhenOnlyPreeditString=False
# Do not show input window if there is only one candidate and preedit
# Available Value:
# True False
#HideInputWindowWhenOnlyOneCandidate=False

