#!/bin/bash

alias cfind="groot-cfind"
alias cdw="cd /mnt/mervin/workspaces"
alias cdbob="cd /mnt/mervin/workspaces/devel/bob"
alias vci-github="vci config https://raw.githubusercontent.com/stonier/repos_index/devel/bionic.yaml"
alias vci-local="vci config file:///mnt/mervin/workspaces/bob/repos_index/bionic.yaml"
alias vimmumbo="vim /mnt/mervin/private/mumbojumbo"

# Newer ls put ''s around filenames if there is a space
alias ls='ls --color=auto -N'
